from venusian import lift, onlyliftedfrom
from venusian.tests.fixtures import (
    categorydecorator,
    categorydecorator2,
    )

@onlyliftedfrom()
class Super(object): # pragma: no cover
    @categorydecorator()
    def hiss(self): pass

    @categorydecorator2()
    def jump(self): pass
        
@lift(('mycategory',))
class Sub(Super): # pragma: no cover
    def hiss(self): pass
    
    def jump(self): pass

    @categorydecorator2()
    def smack(self): pass
    



from venusian.tests.fixtures import decorator

from venusian.tests.fixtures.importonly.two import twofunction # should not be scanned

@decorator(function=True)
def onefunction(request): # pragma: no cover
    return request
